import{a as i,b as p}from"./chunk-YWMYRHSH.js";import"./chunk-T647XABD.js";import{a as t,d as n}from"./chunk-7OTLZ3F4.js";import"./chunk-AYHVMOCO.js";import{a as r,b as s}from"./chunk-QS6EYRSM.js";import"./chunk-V5OGN2E5.js";import"./chunk-HSMHPOLA.js";import"./chunk-W2FKRLXJ.js";import"./chunk-7EEKN3SM.js";import"./chunk-OC5JY5EG.js";import"./chunk-BZFDENKG.js";import"./chunk-JFZLN2FV.js";import"./chunk-J5QU44UY.js";import"./chunk-DFU4A362.js";import"./chunk-RRSJWVRA.js";import"./chunk-HBN5K2J4.js";import"./chunk-7PFZXDIW.js";import"./chunk-TJ5GRELT.js";import"./chunk-AVRBEEAA.js";import"./chunk-4ERZBM5I.js";import"./chunk-NR7A5SQN.js";import"./chunk-FB5J2FGI.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import"./chunk-6POW7SSJ.js";import"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-AJ7ODGYR.js";import"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import{cc as o,dc as e}from"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import"./chunk-HTXYTVN4.js";import"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import"./chunk-WL5U2YIT.js";import{e as a}from"./chunk-ADEKKGI2.js";var c,d=a(()=>{s();p();n();e();c=[{canActivate:[r,t],data:{permissions:[o.MonitoringSystemDashboardView]},providers:[i],path:"",pathMatch:"full",loadComponent:()=>import("./chunk-W3OJDZBY.js").then(m=>m.SystemDashboardComponent)}]});d();export{c as SYSDASHBOARD_ROUTES};
