import{a,b,c,d}from"./chunk-AAHUHSGO.js";import"./chunk-Y7E6TROT.js";import"./chunk-CPNLMJTS.js";import"./chunk-CFSK3HL4.js";import"./chunk-7OTLZ3F4.js";import"./chunk-VR6JTJL5.js";import"./chunk-4QXDGE5P.js";import"./chunk-QS6EYRSM.js";import"./chunk-V5OGN2E5.js";import"./chunk-M6W7VW6E.js";import"./chunk-4FYFA554.js";import"./chunk-Y3SKC4HP.js";import"./chunk-RRSJWVRA.js";import"./chunk-HBN5K2J4.js";import"./chunk-7PFZXDIW.js";import"./chunk-TJ5GRELT.js";import"./chunk-AVRBEEAA.js";import"./chunk-4ERZBM5I.js";import"./chunk-NR7A5SQN.js";import"./chunk-FB5J2FGI.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-AJ7ODGYR.js";import"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import"./chunk-HTXYTVN4.js";import"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import"./chunk-WL5U2YIT.js";import"./chunk-ADEKKGI2.js";d();export{a as PAM_ADMIN_SECTION_ROOT_PERMISSIONS,b as PAM_ADMIN_SECTION_ROUTES,c as PAM_ROUTES};
